@@ -5,17 +5,15 @@ package Msql::Statement;
 @Msql::Statement::ISA = qw(DBI::st);
 
 use strict;
-use vars qw($OPTIMIZE $VERSION $AUTOLOAD);
+use vars qw($VERSION $AUTOLOAD);
 
-$VERSION = '1.2009';
-
-$OPTIMIZE = 0; # controls, which optimization we default to
+$VERSION = '1.2016';
 
 sub fetchrow ($) {
-    my($self) = shift;
-    my($ref) = $self->fetchrow_arrayref;
+    my $self = shift;
+    my $ref = $self->fetchrow_arrayref;
     if ($ref) {
-	@$ref;
+	wantarray ? @$ref : $ref->[0];
     } else {
 	();
     }
@@ -65,7 +63,6 @@ sub length ($) { shift->arrAttr('length') }
 sub maxlength  {
     my $sth = shift;
     my $result;
-    if (!($result = $sth->{'maxlength'})) {
 	$result = [];
 	my ($l);
 	for (0..$sth->numfields-1) {
@@ -89,8 +86,6 @@ sub maxlength  {
 		}
 	    }
 	}
-	$sth->{MAXLENGTH} = $result;
-    }
     return wantarray ? @$result : $result;
 }
 
@@ -129,12 +124,14 @@ sub unctrl {
     $x;
 }
 
+use vars qw($OPTIMIZE); # controls, which optimization we default to
+$OPTIMIZE = 0;
 sub optimize {
     my($self,$arg) = @_;
     if (defined $arg) {
-	return $self->{'OPTIMIZE'} = $arg;
+	$self->{'OPTIMIZE'} = $arg;
     } else {
-	return $self->{'OPTIMIZE'} ||= $OPTIMIZE;
+	$self->{'OPTIMIZE'} ||= $OPTIMIZE;
     }
 }
 
