@@ -5,17 +5,15 @@ package Mysql::Statement;
 @Mysql::Statement::ISA = qw(DBI::st);
 
 use strict;
-use vars qw($OPTIMIZE $VERSION $AUTOLOAD);
+use vars qw($VERSION $AUTOLOAD);
 
-$VERSION = '1.2010';
-
-$OPTIMIZE = 0; # controls, which optimization we default to
+$VERSION = '1.2016';
 
 sub fetchrow ($) {
-    my($self) = shift;
-    my($ref) = $self->fetchrow_arrayref;
+    my $self = shift;
+    my $ref = $self->fetchrow_arrayref;
     if ($ref) {
-	@$ref;
+	wantarray ? @$ref : $ref->[0];
     } else {
 	();
     }
@@ -65,7 +63,7 @@ sub length ($) { shift->arrAttr('length') }
 sub maxlength  {
     my $sth = shift;
     my $result;
-    $result = $sth->fetchinternal('maxlength');
+    $result = $sth->fetchinternal('msql_maxlength');
     return wantarray ? @$result : $result;
 }
 
@@ -97,14 +95,6 @@ sub unctrl {
     $x;
 }
 
-sub optimize {
-    my($self,$arg) = @_;
-    if (defined $arg) {
-	return $self->{'OPTIMIZE'} = $arg;
-    } else {
-	return $self->{'OPTIMIZE'} ||= $OPTIMIZE;
-    }
-}
 
 sub as_string {
     my($sth) = @_;
