@@ -1,6 +1,6 @@
 #   Our beloved Emacs will give us -*- perl -*- mode :-)
 #
-#   $Id: mysql.pm 1.1 Tue, 30 Sep 1997 01:28:08 +0200 joe $
+#   $Id: dbd.pm.in,v 1.2 1998/12/30 00:15:44 joe Exp $
 #
 #   Copyright (c) 1994,1995,1996,1997 Alligator Descartes, Tim Bunce
 #
@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.0209';
+$VERSION = '2.0216-';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -211,13 +211,13 @@ use strict;
 			  );
 
 sub prepare {
-    my($dbh, $statement)= @_;
+    my($dbh, $statement, $attribs)= @_;
 
     # create a 'blank' dbh
     my $sth = DBI::_new_sth($dbh, {'Statement' => $statement});
 
     # Populate internal handle data.
-    if (!DBD::mysql::st::_prepare($sth, $statement)) {
+    if (!DBD::mysql::st::_prepare($sth, $statement, $attribs)) {
 	$sth = undef;
     }
 
@@ -627,9 +627,6 @@ or
   my $sth = $dbh->prepare("QUERY");
   $sth->{"mysql_use_result"} = 1;
 
-Of course it doesn't make sense to set this attribute before calling the
-C<execute> method.
-
 Column dependent attributes, for example I<NAME>, the column names,
 are returned as a reference to an array. The array indices are
 corresponding to the indices of the arrays returned by I<fetchrow>
