@@ -34,7 +34,7 @@
  *           Email: joe@ispsoft.de
  *           Fax: +49 7123 / 14892
  *
- *  $Id: myMsql.h 1.1 Tue, 30 Sep 1997 01:28:08 +0200 joe $
+ *  $Id: myMsql.h,v 1.1.1.1 1998/12/22 14:29:52 joe Exp $
  */
 
 #ifndef MYMSQL_H_INCLUDED
@@ -57,6 +57,7 @@ typedef int dbh_t;
 typedef m_result* result_t;
 typedef m_row row_t;
 typedef m_field* field_t;
+
 #define MyListDbs(s) msqlListDBs(s)
 #define MyListTables(s) msqlListTables(s)
 #define MyListFields(s, t) msqlListFields(s, t)
@@ -68,7 +69,7 @@ typedef m_field* field_t;
 #define MyErrno(s, m) (m)
 #define MyQuery(s, q, l) msqlQuery(s, q)
 #define MyStoreResult(s) msqlStoreResult()
-#define MyGetHostInfo(s) msqlGetHostInfo(s)
+#define MyGetHostInfo(s) msqlGetHostInfo()
 #define MyGetServerInfo(s) msqlGetServerInfo()
 #define MyGetProtoInfo(s) msqlGetProtoInfo()
 #define MyShutdown(s) msqlShutdown(s)
@@ -84,7 +85,6 @@ typedef m_field* field_t;
 #define IS_PRI_KEY(n) ((n) & 4)
 #endif
 
-int MyConnect(dbh_t*, char*, char*, char*);
 #define MyReconnect(s, h) 0
 
 #else
@@ -93,9 +93,11 @@ int MyConnect(dbh_t*, char*, char*, char*);
 #include <errmsg.h>
 
 typedef MYSQL* dbh_t;
+typedef MYSQL* dbh_connect_t;
 typedef MYSQL_RES* result_t;
 typedef MYSQL_ROW row_t;
 typedef MYSQL_FIELD* field_t;
+
 #define MyListDbs(s) mysql_list_dbs(s, NULL)
 #define MyListTables(s) mysql_list_tables(s, NULL)
 #define MyListFields(s, t) mysql_list_fields(s, t, NULL)
@@ -125,7 +127,6 @@ typedef MYSQL_FIELD* field_t;
 #define MyFieldSeek(r, i) mysql_field_seek(r, i)
 #define MyDataSeek(r, i) mysql_data_seek(r, i)
 
-int MyConnect(dbh_t, char*, char*, char*);
 #if MYSQL_VERSION_ID >= 32117
 #define MyReconnect(s, h) (mysql_errno(s) == CR_SERVER_GONE_ERROR)
 #else
@@ -144,4 +145,6 @@ extern int MysqlReconnect(SV*);
 #endif
 
 
+int MyConnect(dbh_t*, char*, char*, char*, char*, char*, char*, imp_dbh_t*);
+
 #endif
